/*
  Patio (Espaol) con fuente (Spanish patio with source).

  --
  Jaime Vives Piqueres, Sept-2003.

  Remake of an old scene ("Fuente", done with POV-Ray 3.0). Sorry for the 
  spanglish comments and variable names...

  Notes:

  + Uses TOMTree by Tom Aust, with modified textures (included). 
  + Uses LightsysIV (not included, visit www.ignorancia.org).

*/
#version 3.5;

// *** global settings ***
#default{texture{finish{ambient 0}}}
#declare usar_rad=0;
#declare use_phot=0;
global_settings{

 max_trace_level 24  // for the water
 assumed_gamma 1.0   

 // load/save rad settings
 #if (usar_rad>0)
 radiosity{
 #if (usar_rad=2)
  pretrace_start .05 pretrace_end .01
  count 50 
  nearest_count 10 error_bound .5
  recursion_limit 1
  normal on
  save_file "patio.rad"
 #else
  pretrace_start 1 pretrace_end 1
  error_bound .5
  recursion_limit 1
  normal on
  always_sample off
  load_file "patio.rad"
 #end
 }
 #end

 // photons for the water
 #if (use_phot)
  photons{
   spacing .2
   autostop 0
  }
 #end
}


// *** standard includes ***
#include "colors.inc"
#include "textures.inc"
#include "metals.inc"
#include "stones.inc"
#include "woods.inc"
#include "skies.inc"
#include "functions.inc"


// *** CIE & LIGHTSYS ***
#include "CIE.inc"
#include "lightsys.inc"          
#include "lightsys_constants.inc" 
#include "espd_lightsys.inc"  // light spectrums
#include "rspd_jvp.inc"       // material samples


// *** Rendering control center ***
#declare trazar_agua=     1; // set to 0 when saving rad
#declare trazar_fuente=   1;
#declare trazar_constr=   1;
#declare trazar_yerba=    1; // set to 0 when saving rad
#declare trazar_plantas=  1;
#declare trazar_arboles=  1;
#declare trazar_puertas=  1;
#declare trazar_ventanas= 1;
#declare trazar_bancos=   1;
#declare trazar_libro=    1;
#declare trazar_diurno=   1;
#declare usar_detalle=    1; // set to 0 when saving rad
#declare usar_relleno=    0; // for tests


// *** globales variables ***
#declare r1=seed(5432);

// *** global functions ***
#include "i_func-mac.inc"

// *** Global textures ***
CIE_ColorSystemWhitepoint(sRGB_ColSys,Illuminant_D50)  // spectometer color system
#include "i_textures.inc"
CIE_ColorSystemWhitepoint(sRGB_ColSys,Illuminant_D55)  // restore scene c.s.


// *** camera ***
// final
#declare desde=<190,165,-550>;
#declare hacia=<0,168,0>;
#declare zoom=<0,0,2.5>;
// arches 2nd floor
/*
#declare desde=<0,400,0>;
#declare hacia=<0,408,500>;
#declare zoom=<0,0,2.5>;
*/
// fountain
/*
#declare desde=<190,165,-550>;
#declare hacia=<0,80,0>;
#declare zoom=<0,0,5>;
*/
// zenital 
/*
#declare desde=<0,1500,0>;
#declare hacia=<0,0,0>;
#declare zoom=<0,0,2.5>;
*/

camera {
 location desde
 up <0,2.4,0> right <3.2,0,0>
 direction zoom
 look_at hacia
}
// *** filling light for tests ***
#if (usar_relleno)
light_source{desde,.5 shadowless}
#end


// *** sky sphere and sun ***
#if (trazar_diurno)
// fake model instead Skylight, with random placement
#declare r_sun=seed(350); 
#declare Al=90*rand(r_sun);
#declare Az=360*rand(r_sun);
#declare lct=2000+4000*Al/90;
#if (lct<4000)
 #declare lc=Blackbody(lct);
#else
 #declare lc=Daylight(lct);
#end
light_source{
 -100000*z
 Light_Color(lc,2+usar_rad)  
// area_light <600,0,0>,<0,600,0>,30,30 jitter adaptive 1 circular orient
 rotate Al*x
 rotate (180-Az)*y
}
#declare sct=2000+12000*Al/90;
#if (sct<4000)
 #declare sc=Blackbody(sct);
#else
 #declare sc=Daylight(sct);
#end
sphere{
 0,101000
 pigment{rgb sc}
 finish{diffuse 0 ambient 1}
}
/*
// or using skylight+sunpos...
#include "sunpos.inc"
//                 YYYY  MM  DD  HH  Mi  LSTM Long lat
#local dump=SunPos(2003, 07, 15, 12, 00, 15,  39,  0);  // valencia, mid september 2003
#declare North=z;
#declare Intensity_Mult=1;
#declare Current_Turbidity=3;
#declare Max_Vertices=800;
#include "CIE_Skylight"
light_source{
 SolarPosition
 Light_Color(SunColor,4)
}
*/
#end


// *** posicionando objetos ***
#if (trazar_fuente=1)
 #include "i_source.inc"
 object{fuente
  scale 0.75
  translate -6*y
 }
#end

#if (trazar_constr=1)
 #include "i_constr.inc"
 #include "i_fence.inc"
 #include "i_columns.inc"
 #include "i_arches.inc"
 #include "i_floor.inc"
 #include "i_house_ceil.inc"
 object{cjto_col1}
 object{cjto_arcos1}
 object{paredes}
 object{pared_ext}
 #if (usar_detalle)
 object{cjto_azulejos}
 #end
 union{
  object{cjto_col2}
  object{cjto_arcos2}
  object{paredes}
  object{pared_ext}
  #if (usar_detalle)
  object{cjto_azulejos}
  #end
  translate 340*y
 }
 #if (usar_rad!=2)
 #end
 object{baranda  translate 340*y }
 object{suelo_arcos translate 340*y}
 object{suelo_arcos translate 680*y}
 object{repisa translate 340*y}
 object{repisa translate 680*y}
 object{cjto_traviesas}
 object{cjto_traviesas rotate 90*y}
 object{cjto_traviesas rotate 90*2*y}
 object{cjto_traviesas rotate 90*3*y}
 object{cjto_traviesas translate 340*y}
 object{cjto_traviesas rotate 90*y translate 340*y}
 object{cjto_traviesas rotate 90*2*y translate 340*y}
 object{cjto_traviesas rotate 90*3*y translate 340*y}
 object{house_ceil rotate 55*x translate <0,770,600>}
 object{house_ceil rotate 55*x translate <0,770,600> rotate 90*y}
 object{house_ceil rotate 55*x translate <0,770,600> rotate 90*2*y}
 object{house_ceil rotate 55*x translate <0,770,600> rotate 90*3*y}
 box{-.5,.5 texture{t_cement} scale <1000,20,1> translate <0,690,500>}
 box{-.5,.5 texture{t_cement} scale <1000,20,1> translate <0,690,500> rotate 90*1*y}
 box{-.5,.5 texture{t_cement} scale <1000,20,1> translate <0,690,500> rotate 90*2*y}
 box{-.5,.5 texture{t_cement} scale <1000,20,1> translate <0,690,500> rotate 90*3*y}
 object{suelo_patio translate 2*y}
 object{huecos_arboles translate 2*y}
 #if (trazar_yerba)
  #include "i_grass.inc"
  object{yerba translate 2*y}
 #end
#end


// *** benchs ***
#if (trazar_bancos=1)
#include "i_stone-bench.inc"
object{banco translate <0,2,245> rotate 45*y}
object{banco translate <0,2,245> rotate (45+90)*y}
object{banco translate <0,2,245> rotate (45+180)*y}
object{banco translate <0,2,245> rotate (45+270)*y}
#include "i_park-bench.inc"
object{garden_bench scale .35 translate <-375,38, 650>}
object{garden_bench scale .35 translate < 375,38, 650>}
object{garden_bench scale .35 rotate -90*y translate <-650,38,-375>}
object{garden_bench scale .35 rotate -90*y translate <-650,38, 375>}
union{
object{garden_bench scale .35 translate <-375,38, 650>}
object{garden_bench scale .35 translate < 375,38, 650>}
object{garden_bench scale .35 rotate -90*y translate <-650,38,-375>}
object{garden_bench scale .35 rotate -90*y translate <-650,38, 375>}
translate 340*y
}
#end


// *** open book on the stone bench ***
#if (trazar_libro)
#include "i_libro_abierto.inc"
object{libro_abierto rotate 110*y
 translate <20,45.5,245> rotate (-45-180-90)*y
}
#end


// *** doors ***
#if (trazar_puertas)
 #include "i_door.inc"
 object{puertas_1}
 object{puertas_1 translate 340*y}
#end


// *** windows ***
#if (trazar_ventanas)
 #include "i_window.inc"
 object{ventanas}
 object{ventanas translate 340*y}
#end


// *** trees ***
#if (trazar_arboles)
#include "palm04.inc" 
#include "TOMTREE.inc"
#declare Tree1=object{TREE scale 500}
object{Tree1 translate <-270,-20, 270>}
object{Tree1 rotate 180*y translate < 270,-10, 270>}
object{Tree1 rotate 90*y translate <-270,-10,-270>}
object{Tree1 rotate 240*y translate < 270,-10,-270>}
#end


// *** Plants ***
#if (trazar_plantas)
// under the arches 
#include "i_plants.inc"
object{planta_maceta1 rotate 360*rand(r1)*y translate <-660,0, 475>}
object{planta_maceta3 rotate 360*rand(r1)*y translate <-660,0, 275>}
object{planta_maceta1 rotate 360*rand(r1)*y translate <-660,0,-275>}
object{planta_maceta3 rotate 360*rand(r1)*y translate <-660,0,-475>}
object{planta_maceta1 rotate 360*rand(r1)*y translate <-475,0,660>}
object{planta_maceta3 rotate 360*rand(r1)*y translate <-275,0,660>}
object{planta_maceta1 rotate 360*rand(r1)*y translate < 275,0,660>}
object{planta_maceta3 rotate 360*rand(r1)*y translate < 475,0,660>}
object{planta_maceta2 rotate 360*rand(r1)*y translate <-660,0, 660>}
object{planta_maceta2 rotate 360*rand(r1)*y translate <-120,0, 660>}
object{planta_maceta2 rotate 360*rand(r1)*y translate < 120,0, 660>}
object{planta_maceta2 rotate 360*rand(r1)*y translate <-660,0, 120>}
union{
//object{planta_maceta1 rotate 360*rand(r1)*y translate <-660,0, 475>}
//object{planta_maceta3 rotate 360*rand(r1)*y translate <-660,0, 275>}
//object{planta_maceta1 rotate 360*rand(r1)*y translate <-660,0,-275>}
//object{planta_maceta3 rotate 360*rand(r1)*y translate <-660,0,-475>}
//object{planta_maceta1 rotate 360*rand(r1)*y translate <-475,0,660>}
//object{planta_maceta3 rotate 360*rand(r1)*y translate <-275,0,660>}
//object{planta_maceta1 rotate 360*rand(r1)*y translate < 275,0,660>}
//object{planta_maceta3 rotate 360*rand(r1)*y translate < 475,0,660>}
object{planta_maceta2 rotate 360*rand(r1)*y translate <-120,0, 660>}
object{planta_maceta2 rotate 360*rand(r1)*y translate < 120,0, 660>}
translate 340*y
}
// near the trees
object{LittlePalm scale 50+25*rand(rlp) rotate 360*rand(rlp)*y translate <-320,0, 150>}
object{LittlePalm scale 50+25*rand(rlp) rotate 360*rand(rlp)*y translate <-150,0, 330>}
object{LittlePalm scale 50+25*rand(rlp) rotate 360*rand(rlp)*y translate < 320,0, 150>}
object{LittlePalm scale 50+25*rand(rlp) rotate 360*rand(rlp)*y translate < 150,0, 330>}
object{LittlePalm scale 50+25*rand(rlp) rotate 360*rand(rlp)*y translate <-320,0,-150>}
//object{LittlePalm scale 50+25*rand(rlp) rotate 360*rand(rlp)*y translate <-150,0,-330>}
//object{LittlePalm scale 50+25*rand(rlp) rotate 360*rand(rlp)*y translate < 320,0,-150>}
//object{LittlePalm scale 50+25*rand(rlp) rotate 360*rand(rlp)*y translate < 150,0,-330>}
object{OtherPlant scale 50+25*rand(rlp) rotate 360*rand(rlp)*y translate <-290,0, 220>}
object{OtherPlant scale 50+25*rand(rlp) rotate 360*rand(rlp)*y translate <-335,0, 260>}
object{OtherPlant scale 50+25*rand(rlp) rotate 360*rand(rlp)*y translate <-285,0, 325>}
object{OtherPlant scale 50+25*rand(rlp) rotate 360*rand(rlp)*y translate < 290,0, 220>}
object{OtherPlant scale 50+25*rand(rlp) rotate 360*rand(rlp)*y translate < 335,0, 260>}
object{OtherPlant scale 50+25*rand(rlp) rotate 360*rand(rlp)*y translate < 285,0, 325>}
object{OtherPlant scale 50+25*rand(rlp) rotate 360*rand(rlp)*y translate <-280,0,-220>}
object{OtherPlant scale 50+25*rand(rlp) rotate 360*rand(rlp)*y translate < 280,0,-220>}
object{planta2 scale 2+rand(rlp) rotate 360*rand(rlp)*y translate <-200,0, 350>}
object{planta2 scale 2+rand(rlp) rotate 360*rand(rlp)*y translate < 200,0, 350>}
object{planta2 scale 2+rand(rlp) rotate 360*rand(rlp)*y translate <-200,0,-250>}
#end

// filling plane
plane{y,-50 pigment{White}}
